%global oversion 1.3.0-rc4

Name:		tcmu-runner
Version:	1.3.0
Release:	0.4%{?dist}
Summary:	A daemon that supports LIO userspace backends

Group:		System Environment/Daemons
License:	ASL 2.0
URL:		https://github.com/open-iscsi/tcmu-runner
Source0:	https://github.com/open-iscsi/${name}/archive/v%{oversion}/%{name}-v%{oversion}.tar.gz

ExclusiveArch:  x86_64

Requires:       libtcmu = %{version}-%{release}
Requires:	librbd1 >= 2:12.1.2
Requires:	targetcli >= 2.1.fb47-0.1

BuildRequires:	cmake
BuildRequires:	glib2-devel
BuildRequires:	kmod-devel
BuildRequires:	libnl3-devel
BuildRequires:	librbd1-devel >= 2:12.1.2
BuildRequires:	systemd-units

%description
A daemon that handles the complexity of the LIO kernel target's userspace
passthrough interface (TCMU). It presents a C plugin API for extension modules
that handle SCSI requests in ways not possible or suitable to be handled
by LIO's in-kernel backstores.

%package -n libtcmu
Summary:        A library to ease supporting LIO userspace processing
Group:          System Environment/Libraries

%description -n libtcmu
libtcmu provides a library for processing SCSI commands exposed by the
LIO kernel target's TCM-User backend.

%package -n libtcmu-devel
Summary:        Development headers for libtcmu
Group:          System Environment/Libraries
Requires:       libtcmu = %{version}-%{release}
Obsoletes:      libtcmu-devel < %{version}-%{release}

%description -n libtcmu-devel
Development header(s) for developing against libtcmu.

%prep
%autosetup -p1 -n %{name}-%{oversion}

%build
%cmake -DSUPPORT_SYSTEMD=ON -Dwith-glfs=false -Dwith-qcow=false .
make %{?_smp_mflags}
gzip --stdout tcmu-runner.8 > tcmu-runner.8.gz

%install
make install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_mandir}/man8/
install -m 644 tcmu-runner.8.gz %{buildroot}%{_mandir}/man8/

%post -p /sbin/ldconfig

%files
%{_bindir}/tcmu-runner
%dir %{_libdir}/tcmu-runner
%{_libdir}/tcmu-runner/*
%{_sysconfdir}/dbus-1/system.d/tcmu-runner.conf
%{_sysconfdir}/tcmu/tcmu.conf
%{_datarootdir}/dbus-1/system-services/org.kernel.TCMUService1.service
%{_unitdir}/tcmu-runner.service
%doc README.md
%license LICENSE
%{_mandir}/man8/tcmu-runner.8.gz

%files -n libtcmu
%{_libdir}/*.so.*

%files -n libtcmu-devel
%{_libdir}/*.so

%changelog
* Thu Sep 28 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.4
- rebased to 1.3.0-rc4

* Sat Sep 09 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.2.4
- libtcmu: fix name check for nl commands

* Tue Sep 05 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.2.3
- libtcmu: move genl_unregister_family to teardown_netlink
- open_handlers: fix dlsym return
- rbd: try to remain cluster's osd op timeout default value
- libtcmu: handle error when netlink family group is not found
- log config: fix tcmu_conf_set_options
- config: fix the default log level in tcmu.conf
- logger: logdir path setting via Env variable 'TCMU_LOGDIR'
- logdir: make log dir configurable in tcmu.conf
- logdir: fix error when making recursion directories
- logdir: move tcmu_logdir_create to log file and make it globally
- logdir: make tcmu_log_dir as static
- README: update and add logger setting and system config sections
- tcmur: fixed possible uninitialized variable warning
- fbo: use get be helpers.
- file_optical: fix strict aliasing rules
- add byteshift helpers
- main: set TCMUR_DEV_FLAG_IS_OPEN on successfully added devices
- libtcmu: fix cfgstring len
- README: fix highlighting the targetcli command looks like a title
- log/file_output: fix and clean up the file output callout
- logdir: add tcmu_logdir_check helper support
- alua:fix untrack when implicit transition not success
- runner: user tcmu_xxx helpers instead of printf
- main: fix crash by --tcmu-log-dir/-l
- tcmu-runner: make the max open files setup as operational
- tcmu-runner: increase max open file descriptors limit
- alua: to make sure the device failover is supported when alau access type is Implicit
- tcmur: fix rhandler->lock NULL pointer dereference
- alua: add failover_is_supported helper support
- rbd: misc fixes
- rbd: Add timers check for cluster osd
- tcmu-runner:fix the exception return value for function tcmu_get_alua_grps()
- tcmu:double free tgt_port in tcmu_get_alua_grp
- tcmu:fix return data length of rtpg response data
- .gitignore: update .gitignore
- runner: add errno info in err logs
- rbd: fix defined but not used warning
- cmake: add -Werror for CFLAGS
- rbd:fix comment in tcmu_rbd_cfg_desc
- runner: scsi debug info convert to tcmu_dev_dbg_scsi_cmd()
- alua: fix enabled_port NULL pointer dereference
- tcmur/unmap_split: reduce the unmap split logs output
- runner: fix main failure path
- libtcmu: merge resources release code
- rbd: Add the header explicitly when needed

* Tue Aug 15 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.2.2
- Depend on librbd1 packages from epoch 2

* Tue Aug 15 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.2.1
- Restrict to x86_64 arch

* Tue Aug 15 2017 Jason Dillaman <dillaman@redhat.com> 1.3.0-0.2
- Rebased to 1.3.0 RC2

